@@ -1,4 +1,4 @@
-# $Id: POE.pm 1988 2006-06-15 15:12:30Z rcaputo $
+# $Id: POE.pm 2183 2007-03-23 06:16:24Z rcaputo $
 # Copyrights and documentation are after __END__.
 
 package POE;
@@ -7,8 +7,8 @@ use strict;
 use Carp qw( croak );
 
 use vars qw($VERSION $REVISION);
-$VERSION = '0.3502';
-$REVISION = do {my($r)=(q$Revision: 1988 $=~/(\d+)/);sprintf"1.%04d",$r};
+$VERSION = '0.9989'; # NOTE - Should be #.#### (four decimal places)
+$REVISION = do {my($r)=(q$Revision: 2183 $=~/(\d+)/);sprintf"1.%04d",$r};
 
 sub import {
   my $self = shift;
@@ -48,7 +48,7 @@ sub import {
     if ($@) {
       warn $@;
       push @failed, "Kernel"
-    };
+    }
   }
 
   # Load all the others.
@@ -66,14 +66,6 @@ sub import {
   @failed and croak "could not import qw(" . join(' ', @failed) . ")";
 }
 
-#------------------------------------------------------------------------------
-
-sub new {
-  my $type = shift;
-  croak "$type is not meant to be used directly";
-}
-
-#------------------------------------------------------------------------------
 1;
 
 __END__
@@ -184,8 +176,9 @@ assume that something doesn't exist if it's not there.
 
 There are also some helper classes.  POE::Pipe is the base class for
 POE::Pipe::OneWay and POE::Pipe::TwoWay.  They are portable pipe
-creation functions, mainly for POE's test suite.  POE::Preprocessor is
-a macro language implemented as a source filter.
+creation functions, mainly for POE's test suite.  POE::Preprocessor, a
+macro language implemented as a source filter, has been split off into
+its own distribution: Filter::Template.
 
 POE is a relatively large system.  It includes internal classes that
 allow it to be customized without needing to know too much about the
@@ -354,8 +347,6 @@ POE::Loop::Select, POE::Loop::Tk
 
 POE::Pipe, POE::Pipe::OneWay, POE::Pipe::TwoWay
 
-POE::Preprocessor
-
 POE::Queue, POE::Queue::Array
 
 POE::Resource, POE::Resource::Aliases, POE::Resource::Events,
