@@ -1,11 +1,11 @@
-# $Id: ReadWrite.pm 1947 2006-04-29 22:58:20Z rcaputo $
+# $Id: ReadWrite.pm 2176 2007-03-12 17:11:46Z rcaputo $
 
 package POE::Wheel::ReadWrite;
 
 use strict;
 
 use vars qw($VERSION);
-$VERSION = do {my($r)=(q$Revision: 1947 $=~/(\d+)/);sprintf"1.%04d",$r};
+$VERSION = do {my($r)=(q$Revision: 2176 $=~/(\d+)/);sprintf"1.%04d",$r};
 
 use Carp qw( croak carp );
 use POE qw(Wheel Driver::SysRW Filter::Line);
@@ -73,8 +73,10 @@ sub new {
 
     # If neither Filter, InputFilter or OutputFilter is defined, then
     # they default to POE::Filter::Line.
-    unless (defined $in_filter or defined $out_filter) {
-      $in_filter = $out_filter = POE::Filter::Line->new();
+    unless (defined $in_filter and defined $out_filter) {
+      my $new_filter = POE::Filter::Line->new();
+      $in_filter = $new_filter unless defined $in_filter;
+      $out_filter = $new_filter unless defined $out_filter;
     }
   }
 
@@ -699,26 +701,38 @@ ReadWrite performs buffered, select-based I/O on filehandles.  It
 generates events for common file conditions, such as when data has
 been read or flushed.
 
+=head1 CONSTRUCTOR
+
+=over
+
+=item new
+
+new() creates a new wheel, returning the wheels reference.
+
+=back
+
 =head1 PUBLIC METHODS
 
 =over 2
 
-=item put ARRAYREF_OF_RECORDS
+=item put RECORDS
 
-put() queues records for transmission.  They may not be transmitted
-immediately.  ReadWrite uses its Filter to translate the records into
-a form suitable for writing.  It uses its Driver to queue and send
-them.
+put() queues one or more RECORDS for transmission.  Each record is of
+a form dictated by POE::Wheel::ReadWrite's current output filter.
+ReadWrite uses its output filter to translate the records into a form
+suitable for writing to a stream.  It uses the currently configured
+driver to buffer and send them.
 
-put() accepts a list of records.  It returns a boolean value
-indicating whether the wheel's high-water mark has been reached.  It
-always returns false if a wheel doesn't have a high-water mark set.
+put() accepts a list of records.  If a high water mark has been set,
+it returns a Boolean value indicating whether the driver's output
+buffer has reached that level.  It always returns false if a high
+water mark has not been set.
 
-This will quickly fill a wheel's output queue if it has a high-water
-mark set.  Otherwise it will loop infinitely, eventually exhausting
-memory.
+This example will quickly fill a wheel's output queue if it has a
+high water mark set.  Otherwise it will loop infinitely, eventually
+exhausting memory and crashing.
 
-  1 while $wheel->put( &get_next_thing_to_send );
+  1 while $wheel->put( get_next_thing_to_send() );
 
 =item event EVENT_TYPE => EVENT_NAME, ...
 
@@ -793,6 +807,12 @@ Some applications require the remote end to shut down a socket before
 they will continue.  These methods map directly to shutdown() for the
 wheel's input and output sockets.
 
+=item get_driver_out_octets
+
+=item get_driver_out_messages
+
+Return driver statistics.
+
 =back
 
 =head1 EVENTS AND PARAMETERS
