@@ -1,12 +1,11 @@
-# $Id: SocketFactory.pm,v 1.81 2005/07/01 03:19:44 rcaputo Exp $
+# $Id: SocketFactory.pm 2106 2006-09-05 14:18:29Z bingosnet $
 
 package POE::Wheel::SocketFactory;
-use POE::Preprocessor ( isa => "POE::Macro::UseBytes" );
 
 use strict;
 
 use vars qw($VERSION);
-$VERSION = do {my@r=(q$Revision: 1.81 $=~/\d+/g);sprintf"%d."."%04d"x$#r,@r};
+$VERSION = do {my($r)=(q$Revision: 2106 $=~/(\d+)/);sprintf"1.%04d",$r};
 
 use Carp qw( carp croak );
 use Symbol qw( gensym );
@@ -46,9 +45,13 @@ sub MY_SOCKET_SELECTED () { 12 }
 
 # Provide dummy constants for systems that don't have them.
 BEGIN {
-  unless (exists $INC{"Socket6.pm"}) {
-    eval "*Socket6::AF_INET6 = sub () { ~0 }";
-    eval "*Socket6::PF_INET6 = sub () { ~0 }";
+  eval {
+    require Socket6;
+    my $x = &Socket6::AF_INET6;
+  };
+  if ($@) {
+    *Socket6::AF_INET6 = sub () { ~0 };
+    *Socket6::PF_INET6 = sub () { ~0 };
   }
 }
 
@@ -108,7 +111,7 @@ my %default_socket_type = (
 # Perform system-dependent translations on Unix addresses, if
 # necessary.
 
-sub condition_unix_address {
+sub _condition_unix_address {
   my ($address) = @_;
 
   # OS/2 would like sockets to use backwhacks, and please place them
@@ -713,7 +716,8 @@ sub new {
         : INADDR_ANY
       );
 
-      {% use_bytes %}
+      # Need to check lengths in octets, not characters.
+      use bytes;
 
       # Resolve the bind address if it's not already packed.
       unless (length($bind_address) == 4) {
@@ -785,7 +789,8 @@ sub new {
         }
       }
 
-      {% use_bytes %}
+      # Need to check lengths in octets, not characters.
+      use bytes;
 
       # Resolve the bind address.
       my @info = Socket6::getaddrinfo(
@@ -822,7 +827,7 @@ sub new {
         return $self;
       }
 
-      $bind_address = &condition_unix_address($params{BindAddress});
+      $bind_address = &_condition_unix_address($params{BindAddress});
       $bind_address = pack_sockaddr_un($bind_address);
       unless ($bind_address) {
         $poe_kernel->yield(
@@ -949,7 +954,7 @@ sub new {
     # understands.
     elsif ($abstract_domain eq DOM_UNIX) {
 
-      $connect_address = condition_unix_address($params{RemoteAddress});
+      $connect_address = _condition_unix_address($params{RemoteAddress});
       $connect_address = pack_sockaddr_un($connect_address);
       unless (defined $connect_address) {
         $poe_kernel->yield(
