@@ -1,5 +1,5 @@
 #!/usr/bin/perl
-# $Id: Makefile-5004.pm 1970 2006-05-30 19:15:22Z bsmith $
+# $Id: Makefile-5004.pm 2147 2006-11-02 20:06:03Z bsmith $
 
 use strict;
 
@@ -7,6 +7,7 @@ use ExtUtils::MakeMaker;
 
 use lib qw(./mylib);
 use PoeBuildInfo qw(
+  TEST_FILES
   CLEAN_FILES
   CORE_REQUIREMENTS
 );
@@ -54,8 +55,13 @@ WriteMakefile(
     FILES => CLEAN_FILES,
   },
 
-  PL_FILES    => { },
+  test => {
+    TESTS => TEST_FILES,
+  },
+
+  PL_FILES  => { },
   PREREQ_PM => { CORE_REQUIREMENTS },
+  PM_FILTER => 'mylib/preprocessor.perl',
 );
 
 1;
